import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_midi_platform_interface/platform_interface.dart';
import 'package:flutter_web_plugins/flutter_web_plugins.dart';
import 'package:tonic/tonic.dart' as tonic;

import 'dart:js' as js;
import 'dart:html' as html;

class FlutterMidiWeb extends FlutterMidiPlatform {
  static const MethodChannel _channel = MethodChannel('flutter_midi');

  static void registerWith(Registrar registrar) {
    FlutterMidiPlatform.instance = FlutterMidiPlatform();
  }

  static String midi2name(int number) =>
      "${tonic.flatNoteNames[number % 12]}${number ~/ 12 - 1}";

  /// Use this when stopping the sound onTouchUp or to cancel a long file.
  /// Not needed if playing midi onTap.
  @override
  Future<String> stopMidiNote({
    @required int midi,
  }) async {
    String _note = tonic.Pitch.fromMidiNumber(midi).toString();
    _note = _note.replaceAll('♭', 'b').replaceAll('♯', '#');
    // print('Midi -> $midi/$_note');
    js.context.callMethod("stopNote", ["$_note", "8n"]);
    // html.window.document.getElementById('midiPlay$midi').click();
    return "";
  }

  /// Play a midi note from the sound_font.SF2 library bundled with the application.
  /// Play a midi note in the range between 0-256
  /// Multiple notes can be played at once as seperate calls.
  @override
  Future<String> playMidiNote({
    @required int midi,
  }) async {
    String _note = tonic.Pitch.fromMidiNumber(midi).toString();
    _note = _note.replaceAll('♭', 'b').replaceAll('♯', '#');
    // print('Midi -> $midi/$_note');
    js.context.callMethod("playNote", ["$_note", "8n"]);
    // html.window.document.getElementById('midiPlay$midi').click();
    return "";
  }
}
